const { SlashCommandBuilder } = require('discord.js');

module.exports = {
    data: new SlashCommandBuilder()
        .setName('ban')
        .setDescription('Zbanuj użytkownika na serwerze')
        .addUserOption(option =>
            option.setName('kogo')
                .setDescription('Osoba, którą chcesz zbanować')
                .setRequired(true)
        )
        .addStringOption(option =>
            option.setName('powod')
                .setDescription('Powód zbanowania')
                .setRequired(true)
        ),

    async execute(interaction) {
        const targetUser = interaction.options.getUser('kogo');
        const reason = interaction.options.getString('powod');

        if (!interaction.member.permissions.has('BAN_MEMBERS')) {
            return interaction.reply({ content: 'Nie masz uprawnień do banowania użytkowników.', ephemeral: true });
        }

        if (!targetUser) {
            return interaction.reply({ content: 'Nie znaleziono użytkownika.', ephemeral: true });
        }

        const memberToBan = interaction.guild.members.cache.get(targetUser.id);

        if (!memberToBan) {
            return interaction.reply({ content: 'Nie można znaleźć podanego użytkownika na serwerze.', ephemeral: true });
        }

        try {
            await memberToBan.ban({ reason });

            const embedMessage = {
                type: 'rich',
                title: 'Użytkownik Zbanowany',
                description: `<@${targetUser.id}> spadł z rowerka i się wypierdolił, a głupi ryj rozpierdolił.`,
                image: {
                    url: 'https://images-ext-1.discordapp.net/external/YQW306JidTtWw8WDal6tYaZ7ekiUGPoxUOePrLlDqS4/https/jakzdrowozyc.pl/wp-content/uploads/2014/05/zul1.jpg?format=webp',
                },
                color: 0xff0000,
                footer: {
                    text: 'Data: ' + new Date().toLocaleString(),
                },
            };

            const channelID = '1212337557115773008'; 
            const channel = interaction.guild.channels.cache.get(channelID);

            if (channel) {
                channel.send({ embeds: [embedMessage] });
            }

            interaction.reply({ content: `Pomyślnie zbanowano <@${targetUser.id}> na serwerze. Powód: ${reason}`, ephemeral: true });
        } catch (error) {
            console.error(error);
            interaction.reply({ content: 'Wystąpił błąd podczas banowania użytkownika.', ephemeral: true });
        }
    },
};
